/*
	File:		ProxyToken.h

	Contains:	Proxies (base class for things such as the selection)

	Written by:	Greg Anderson

	Copyright:	 1993-1995 by Apple Computer, Inc., all rights reserved.

		 <5>	 6/23/95	ga		
*/


#ifndef __PROXYTOKEN__
#define __PROXYTOKEN__
#define ProxyToken_h

//
// AbstractDesignator.h is needed because
// TAbstractDesignator is the base class of TProxyToken
//
#include "AbstractDesignator.h"

//
// AbstractProperty.h is needed because
// TGenericProperty is the base class of TPropertyOfProxy
//
#include "AbstractProperty.h"

#define cProxy		'prxy'

class TProxyToken : public TAbstractDesignator
	{
public:
	DeclareSmallClassData(TProxyToken, TAbstractDesignator);

										TProxyToken();
	virtual								~TProxyToken();
	
	void								IProxyToken(TAbstractScriptableObject* objectOfDesignation = nil);

	virtual Boolean						DerivedFromOSLClass(const TAETransaction& t, DescType objectClass);
	virtual DescType					DefaultType(const TAETransaction& t, DescType propertyName);
	virtual DescType					BestType(const TAETransaction& t, DescType propertyName);

	virtual Boolean						Exists(const TAETransaction&);
	virtual TAbstractObjectIterator*	DirectObjectIterator(const TAETransaction&);

	virtual Boolean						PropertyAppliesToProxy(DescType propertyName);
	virtual TAbstractScriptableObject*	AccessByOrdinal(const TAETransaction& t, DescType desiredClass, DescType ordinal);
	virtual TAbstractScriptableObject*	AccessByProperty(const TAETransaction& t, DescType prop);

	// Event Handlers:

//	virtual TDescriptor					GetData(DescType requestedType);
//	virtual void						SetData(TDescriptor keyData);

	virtual TDescriptor					GetProperty(const TAETransaction& t, DescType propertyName, DescType desiredType, unsigned long additionalInfo = 0);
	virtual void						SetProperty(const TAETransaction& t, DescType propertyName, TDescriptor& data, unsigned long additionalInfo = 0);

	virtual TDescriptor					BuildObjectSpecifier(const TAETransaction&);
	virtual Boolean						CanReturnDataOfType(const TAETransaction& t, DescType propertyName, DescType desiredType);

	TPropertyDescription				LookupPropertyDesciption(const TAETransaction& t, DescType propertyIdentifier);

	virtual TDescriptor					AECommandDispatch(const TAETransaction& t, long aeCommandID, long auxInfo = 0);
	virtual TDescriptor					AECommand(const TAETransaction& t, long aeCommandID, TAbstractScriptableObject* auxObjects = nil, long auxInfo = 0);
	virtual TAbstractScriptableObject*	CreateNewElement(const TAETransaction& t, DescType newObjectClass, TDescriptor initialData, TDescriptor initialProperties, Boolean& usedInitialData, Boolean& usedInitialProperties);

protected:
	};

#endif
